@@ -244,7 +244,7 @@ impl<'a> Decryptor<'a> {
         // 1. Copy any buffered data.
         if !self.buffer.is_empty() {
             let to_copy = cmp::min(self.buffer.len(), plaintext.len());
-            &plaintext[..to_copy].copy_from_slice(&self.buffer[..to_copy]);
+            plaintext[..to_copy].copy_from_slice(&self.buffer[..to_copy]);
             crate::vec_drain_prefix(&mut self.buffer, to_copy);
 
             pos = to_copy;
@@ -361,7 +361,7 @@ impl<'a> Decryptor<'a> {
                     assert!(0 < to_copy);
                     assert!(to_copy < self.chunk_size);
 
-                    &plaintext[pos..pos + to_copy]
+                    plaintext[pos..pos + to_copy]
                         .copy_from_slice(&self.buffer[..to_copy]);
                     crate::vec_drain_prefix(&mut self.buffer, to_copy);
                     pos += to_copy;
@@ -804,6 +804,8 @@ mod tests {
     fn roundtrip() {
         use std::io::Cursor;
 
+        // EAX and OCB can be used with all symmetric algorithms using
+        // a 16-byte block size.
         for sym_algo in [SymmetricAlgorithm::AES128,
                          SymmetricAlgorithm::AES192,
                          SymmetricAlgorithm::AES256,
@@ -813,7 +815,18 @@ mod tests {
                          SymmetricAlgorithm::Camellia256]
                          .iter()
                          .filter(|algo| algo.is_supported()) {
-            for aead in [AEADAlgorithm::EAX].iter() {
+
+            if cfg!(feature = "crypto-rust")
+                && sym_algo == &SymmetricAlgorithm::Twofish {
+                    eprintln!("XXX: Skipping Twofish until Twofish \
+                               implements Clone");
+                    continue;
+            }
+
+            for aead in [
+                AEADAlgorithm::EAX,
+                AEADAlgorithm::OCB,
+            ].iter().filter(|algo| algo.is_supported()) {
                 let version = 1;
                 let chunk_size = 64;
                 let mut key = vec![0; sym_algo.key_size().unwrap()];
