@@ -1,8 +1,8 @@
 //! Hold the implementation of [`Signer`] and [`Decryptor`] for [`KeyPair`].
 //!
-//! [`Signer`]: ../../asymmetric/trait.Signer.html
-//! [`Decryptor`]: ../../asymmetric/trait.Decryptor.html
-//! [`KeyPair`]: ../../asymmetric/struct.KeyPair.html
+//! [`Signer`]: super::super::asymmetric::Signer
+//! [`Decryptor`]: super::super::asymmetric::Decryptor
+//! [`KeyPair`]: super::super::asymmetric::KeyPair
 
 use nettle::{curve25519, ecc, ecdh, ecdsa, ed25519, dsa, rsa, random::Yarrow};
 
@@ -85,21 +85,13 @@ impl Signer for KeyPair {
                     // zeros to be stripped.
                     // Padding has to be unconditional; otherwise we have a
                     // secret-dependent branch.
-                    let missing = ed25519::ED25519_KEY_SIZE
-                        .saturating_sub(scalar.value().len());
-                    let mut sec = [0u8; ed25519::ED25519_KEY_SIZE];
-                    sec[missing..].copy_from_slice(scalar.value());
+                    let sec = scalar.value_padded(ed25519::ED25519_KEY_SIZE);
 
-                    let res = ed25519::sign(public, &sec[..], digest, &mut sig);
-                    unsafe {
-                        memsec::memzero(sec.as_mut_ptr(),
-                                        ed25519::ED25519_KEY_SIZE);
-                    }
-                    res?;
+                    ed25519::sign(public, &sec[..], digest, &mut sig)?;
 
                     Ok(mpi::Signature::EdDSA {
-                        r: MPI::new(&sig[..32]),
-                        s: MPI::new(&sig[32..]),
+                        r: MPI::new(&sig[..ed25519::ED25519_KEY_SIZE]),
+                        s: MPI::new(&sig[ed25519::ED25519_KEY_SIZE..]),
                     })
                 },
                 _ => Err(
@@ -242,6 +234,10 @@ impl<P: key::KeyParts, R: key::KeyRole> Key<P, R> {
     {
         use crate::crypto::mpi::Signature;
 
+        fn bad(e: impl ToString) -> anyhow::Error {
+            Error::BadSignature(e.to_string()).into()
+        }
+
         let ok = match (self.mpis(), sig) {
             (PublicKey::RSA { e, n }, Signature::RSA { s }) => {
                 let key = rsa::PublicKey::new(n.value(), e.value())?;
@@ -279,26 +275,14 @@ impl<P: key::KeyParts, R: key::KeyRole> Key<P, R> {
                     // We need to zero-pad them at the front, because
                     // the MPI encoding drops leading zero bytes.
                     let half = ed25519::ED25519_SIGNATURE_SIZE / 2;
-                    if r.value().len() < half {
-                        for _ in 0..half - r.value().len() {
-                            signature.push(0);
-                        }
-                    }
-                    signature.extend_from_slice(r.value());
-                    if s.value().len() < half {
-                        for _ in 0..half - s.value().len() {
-                            signature.push(0);
-                        }
-                    }
-                    signature.extend_from_slice(s.value());
+                    signature.extend_from_slice(
+                        &r.value_padded(half).map_err(bad)?);
+                    signature.extend_from_slice(
+                        &s.value_padded(half).map_err(bad)?);
 
                     // Let's see if we got it right.
-                    if signature.len() != ed25519::ED25519_SIGNATURE_SIZE {
-                        return Err(Error::MalformedPacket(
-                            format!(
-                                "Invalid signature size: {}, r: {:?}, s: {:?}",
-                                signature.len(), r.value(), s.value())).into());
-                    }
+                    assert_eq!(signature.len(),
+                               ed25519::ED25519_SIGNATURE_SIZE);
 
                     ed25519::verify(&q.value()[1..], digest, &signature)?
                 },
@@ -402,6 +386,7 @@ impl<R> Key4<SecretParts, R>
     /// The RSA key will use public exponent `e` and modulo `n`. The key will
     /// have it's creation date set to `ctime` or the current time if `None`
     /// is given.
+    #[allow(clippy::many_single_char_names)]
     pub fn import_secret_rsa<T>(d: &[u8], p: &[u8], q: &[u8], ctime: T)
         -> Result<Self> where T: Into<Option<SystemTime>>
     {
