@@ -130,32 +130,25 @@
 //!
 //! [packet based]: https://tools.ietf.org/html/rfc4880#section-5
 //! [the grammar]: https://tools.ietf.org/html/rfc4880#section-11
-//! [`Signature`]: enum.Signature.html
 //! [v3]: https://tools.ietf.org/html/rfc4880#section-5.2.2
 //! [v4]: https://tools.ietf.org/html/rfc4880#section-5.2.3
-//! [`OnePassSig`]: enum.OnePassSig.html
-//! [parsing a message]: ../parse/index.html
-//! [creating a message]: ../serialize/stream/index.html
-//! [`SignatureBuilder`]: signature/struct.SignatureBuilder.html
+//! [parsing a message]: crate::parse
+//! [creating a message]: crate::serialize::stream
+//! [`SignatureBuilder`]: signature::SignatureBuilder
 //! [`SED`]: https://tools.ietf.org/html/rfc4880#section-5.7
-//! [`Unknown`]: struct.Unknown.html
 //! [private extensions]: https://tools.ietf.org/html/rfc4880#section-4.3
-//! [`Compressed Data`]: struct.CompressedData.html
-//! [parses]: ../parse/index.html
+//! [`Compressed Data`]: CompressedData
+//! [parses]: crate::parse
 //! [OpenPGP Message]: https://tools.ietf.org/html/rfc4880#section-11.3
-//! [`Container::descendants`]: struct.Container.html#method.descendants
-//! [`Deref`]: https://doc.rust-lang.org/stable/std/ops/trait.Deref.html
-//! [`Container`]: struct.Container.html
-//! [`Signature`]: enum.Signature.html
-//! [`SubpacketArea`]: signature/subpacket/struct.SubpacketArea.html
-//! [`Literal`]: struct.Literal.html
-//! [`Body`]: enum.Body.html
-//! [`Eq`]: https://doc.rust-lang.org/stable/std/cmp/trait.Eq.html
-//! [`Key`s]: enum.Key.html
-//! [`CTB`]: header/enum.CTB.html
+//! [`Container::descendants`]: Container::descendants()
+//! [`Deref`]: std::ops::Deref
+//! [`SubpacketArea`]: signature::subpacket::SubpacketArea
+//! [`Eq`]: std::cmp::Eq
+//! [`Key`s]: Key
+//! [`CTB`]: header::CTB
 //! [length style]: https://tools.ietf.org/html/rfc4880#section-4.2
 //! [partial body encoding]: https://tools.ietf.org/html/rfc4880#section-4.2.2.4
-//! [`Key::public_cmp`]: enum.Key.html#method.public_cmp
+//! [`Key::public_cmp`]: Key::public_cmp()
 use std::fmt;
 use std::hash::Hasher;
 use std::ops::{Deref, DerefMut};
@@ -337,24 +330,24 @@ impl Packet {
     ///   [Section 4.3 of RFC 4880]: https://tools.ietf.org/html/rfc4880#section-4.3
     pub fn tag(&self) -> Tag {
         match self {
-            &Packet::Unknown(ref packet) => packet.tag(),
-            &Packet::Signature(_) => Tag::Signature,
-            &Packet::OnePassSig(_) => Tag::OnePassSig,
-            &Packet::PublicKey(_) => Tag::PublicKey,
-            &Packet::PublicSubkey(_) => Tag::PublicSubkey,
-            &Packet::SecretKey(_) => Tag::SecretKey,
-            &Packet::SecretSubkey(_) => Tag::SecretSubkey,
-            &Packet::Marker(_) => Tag::Marker,
-            &Packet::Trust(_) => Tag::Trust,
-            &Packet::UserID(_) => Tag::UserID,
-            &Packet::UserAttribute(_) => Tag::UserAttribute,
-            &Packet::Literal(_) => Tag::Literal,
-            &Packet::CompressedData(_) => Tag::CompressedData,
-            &Packet::PKESK(_) => Tag::PKESK,
-            &Packet::SKESK(_) => Tag::SKESK,
-            &Packet::SEIP(_) => Tag::SEIP,
-            &Packet::MDC(_) => Tag::MDC,
-            &Packet::AED(_) => Tag::AED,
+            Packet::Unknown(ref packet) => packet.tag(),
+            Packet::Signature(_) => Tag::Signature,
+            Packet::OnePassSig(_) => Tag::OnePassSig,
+            Packet::PublicKey(_) => Tag::PublicKey,
+            Packet::PublicSubkey(_) => Tag::PublicSubkey,
+            Packet::SecretKey(_) => Tag::SecretKey,
+            Packet::SecretSubkey(_) => Tag::SecretSubkey,
+            Packet::Marker(_) => Tag::Marker,
+            Packet::Trust(_) => Tag::Trust,
+            Packet::UserID(_) => Tag::UserID,
+            Packet::UserAttribute(_) => Tag::UserAttribute,
+            Packet::Literal(_) => Tag::Literal,
+            Packet::CompressedData(_) => Tag::CompressedData,
+            Packet::PKESK(_) => Tag::PKESK,
+            Packet::SKESK(_) => Tag::SKESK,
+            Packet::SEIP(_) => Tag::SEIP,
+            Packet::MDC(_) => Tag::MDC,
+            Packet::AED(_) => Tag::AED,
         }
     }
 
@@ -367,7 +360,7 @@ impl Packet {
     /// whereas `kind()` returns `None`.
     pub fn kind(&self) -> Option<Tag> {
         match self {
-            &Packet::Unknown(_) => None,
+            Packet::Unknown(_) => None,
             _ => Some(self.tag()),
         }
     }
@@ -380,12 +373,12 @@ impl Packet {
     ///   - The unhashed subpacket area of Signature packets.
     ///   - Secret key material.
     ///
-    ///   [`Hash`]: https://doc.rust-lang.org/stable/std/hash/trait.Hash.html
+    ///   [`Hash`]: std::hash::Hash
     ///
     /// Unlike [`Signature::normalize`], this method ignores
     /// authenticated packets in the unhashed subpacket area.
     ///
-    ///   [`Signature::normalize`]: struct.Signature.html#method.normalize
+    ///   [`Signature::normalize`]: Signature::normalize()
     pub fn normalized_hash<H>(&self, state: &mut H)
         where H: Hasher
     {
@@ -420,25 +413,25 @@ impl Deref for Packet {
 
     fn deref(&self) -> &Self::Target {
         match self {
-            &Packet::Unknown(ref packet) => &packet.common,
-            &Packet::Signature(ref packet) => &packet.common,
-            &Packet::OnePassSig(ref packet) => &packet.common,
-            &Packet::PublicKey(ref packet) => &packet.common,
-            &Packet::PublicSubkey(ref packet) => &packet.common,
-            &Packet::SecretKey(ref packet) => &packet.common,
-            &Packet::SecretSubkey(ref packet) => &packet.common,
-            &Packet::Marker(ref packet) => &packet.common,
-            &Packet::Trust(ref packet) => &packet.common,
-            &Packet::UserID(ref packet) => &packet.common,
-            &Packet::UserAttribute(ref packet) => &packet.common,
-            &Packet::Literal(ref packet) => &packet.common,
-            &Packet::CompressedData(ref packet) => &packet.common,
-            &Packet::PKESK(ref packet) => &packet.common,
-            &Packet::SKESK(SKESK::V4(ref packet)) => &packet.common,
-            &Packet::SKESK(SKESK::V5(ref packet)) => &packet.skesk4.common,
-            &Packet::SEIP(ref packet) => &packet.common,
-            &Packet::MDC(ref packet) => &packet.common,
-            &Packet::AED(ref packet) => &packet.common,
+            Packet::Unknown(ref packet) => &packet.common,
+            Packet::Signature(ref packet) => &packet.common,
+            Packet::OnePassSig(ref packet) => &packet.common,
+            Packet::PublicKey(ref packet) => &packet.common,
+            Packet::PublicSubkey(ref packet) => &packet.common,
+            Packet::SecretKey(ref packet) => &packet.common,
+            Packet::SecretSubkey(ref packet) => &packet.common,
+            Packet::Marker(ref packet) => &packet.common,
+            Packet::Trust(ref packet) => &packet.common,
+            Packet::UserID(ref packet) => &packet.common,
+            Packet::UserAttribute(ref packet) => &packet.common,
+            Packet::Literal(ref packet) => &packet.common,
+            Packet::CompressedData(ref packet) => &packet.common,
+            Packet::PKESK(ref packet) => &packet.common,
+            Packet::SKESK(SKESK::V4(ref packet)) => &packet.common,
+            Packet::SKESK(SKESK::V5(ref packet)) => &packet.skesk4.common,
+            Packet::SEIP(ref packet) => &packet.common,
+            Packet::MDC(ref packet) => &packet.common,
+            Packet::AED(ref packet) => &packet.common,
         }
     }
 }
@@ -446,25 +439,25 @@ impl Deref for Packet {
 impl DerefMut for Packet {
     fn deref_mut(&mut self) -> &mut Common {
         match self {
-            &mut Packet::Unknown(ref mut packet) => &mut packet.common,
-            &mut Packet::Signature(ref mut packet) => &mut packet.common,
-            &mut Packet::OnePassSig(ref mut packet) => &mut packet.common,
-            &mut Packet::PublicKey(ref mut packet) => &mut packet.common,
-            &mut Packet::PublicSubkey(ref mut packet) => &mut packet.common,
-            &mut Packet::SecretKey(ref mut packet) => &mut packet.common,
-            &mut Packet::SecretSubkey(ref mut packet) => &mut packet.common,
-            &mut Packet::Marker(ref mut packet) => &mut packet.common,
-            &mut Packet::Trust(ref mut packet) => &mut packet.common,
-            &mut Packet::UserID(ref mut packet) => &mut packet.common,
-            &mut Packet::UserAttribute(ref mut packet) => &mut packet.common,
-            &mut Packet::Literal(ref mut packet) => &mut packet.common,
-            &mut Packet::CompressedData(ref mut packet) => &mut packet.common,
-            &mut Packet::PKESK(ref mut packet) => &mut packet.common,
-            &mut Packet::SKESK(SKESK::V4(ref mut packet)) => &mut packet.common,
-            &mut Packet::SKESK(SKESK::V5(ref mut packet)) => &mut packet.skesk4.common,
-            &mut Packet::SEIP(ref mut packet) => &mut packet.common,
-            &mut Packet::MDC(ref mut packet) => &mut packet.common,
-            &mut Packet::AED(ref mut packet) => &mut packet.common,
+            Packet::Unknown(ref mut packet) => &mut packet.common,
+            Packet::Signature(ref mut packet) => &mut packet.common,
+            Packet::OnePassSig(ref mut packet) => &mut packet.common,
+            Packet::PublicKey(ref mut packet) => &mut packet.common,
+            Packet::PublicSubkey(ref mut packet) => &mut packet.common,
+            Packet::SecretKey(ref mut packet) => &mut packet.common,
+            Packet::SecretSubkey(ref mut packet) => &mut packet.common,
+            Packet::Marker(ref mut packet) => &mut packet.common,
+            Packet::Trust(ref mut packet) => &mut packet.common,
+            Packet::UserID(ref mut packet) => &mut packet.common,
+            Packet::UserAttribute(ref mut packet) => &mut packet.common,
+            Packet::Literal(ref mut packet) => &mut packet.common,
+            Packet::CompressedData(ref mut packet) => &mut packet.common,
+            Packet::PKESK(ref mut packet) => &mut packet.common,
+            Packet::SKESK(SKESK::V4(ref mut packet)) => &mut packet.common,
+            Packet::SKESK(SKESK::V5(ref mut packet)) => &mut packet.skesk4.common,
+            Packet::SEIP(ref mut packet) => &mut packet.common,
+            Packet::MDC(ref mut packet) => &mut packet.common,
+            Packet::AED(ref mut packet) => &mut packet.common,
         }
     }
 }
@@ -635,13 +628,9 @@ impl std::hash::Hash for Common {
 /// This is returned by [`PacketPile::descendants`] and
 /// [`Container::descendants`].
 ///
-/// [`Packet`]: enum.Packet.html
-/// [container `Packet`s]: index.html#containers
-/// [`CompressedData`]: struct.CompressedData.html
-/// [`SEIP`]: enum.SEIP.html
-/// [`AED`]: enum.AED.html
-/// [`PacketPile::descendants`]: ../struct.PacketPile.html#method.descendants
-/// [`Container::descendants`]: struct.Container.html#method.descendants
+/// [container `Packet`s]: self#containers
+/// [`PacketPile::descendants`]: super::PacketPile::descendants()
+/// [`Container::descendants`]: Container::descendants()
 pub struct Iter<'a> {
     // An iterator over the current message's children.
     children: slice::Iter<'a, Packet>,
@@ -708,7 +697,7 @@ impl<'a> Iter<'a> {
     /// See [`PacketPile::path_ref`] for an explanation of
     /// `pathspec`s.
     ///
-    /// [`PacketPile::path_ref`]: ../struct.PacketPile.html#path_ref
+    /// [`PacketPile::path_ref`]: super::PacketPile#path_ref
     ///
     /// # Examples
     ///
@@ -779,8 +768,7 @@ impl<'a> Iter<'a> {
 ///
 /// Like [`Iter::enumerate`].
 ///
-/// [`Iter::enumerate`]: https://doc.rust-lang.org/stable/std/iter/trait.Iterator.html#method.enumerate
-/// [`Iter`]: struct.Iter.html
+/// [`Iter::enumerate`]: std::iter::Iterator::enumerate()
 struct PacketPathIter<'a> {
     iter: Iter<'a>,
 
@@ -904,14 +892,14 @@ fn packet_path_iter() {
 /// the [`SignatureBuilder`] to create the `Signature` packet.  See
 /// the linked documentation for details, and examples.
 ///
-/// [streaming `Signer`]: ../serialize/stream/struct.Signer.html
-/// [`PacketParser`]: ../parse/index.html
-/// [self signatures on Keys]: enum.Key.html#method.bind
-/// [self signatures on User IDs]: struct.UserID.html#method.bind
-/// [self signatures on User Attributes]: user_attribute/struct.UserAttribute.html#method.bind
-/// [certifications of User IDs]: struct.UserID.html#method.certify
-/// [certifications of User Attributes]: user_attribute/struct.UserAttribute.html#method.certify
-/// [`SignatureBuilder`]: signature/struct.SignatureBuilder.html
+/// [streaming `Signer`]: crate::serialize::stream::Signer
+/// [`PacketParser`]: crate::parse::PacketParser
+/// [self signatures on Keys]: Key::bind()
+/// [self signatures on User IDs]: UserID::bind()
+/// [self signatures on User Attributes]: user_attribute::UserAttribute::bind()
+/// [certifications of User IDs]: UserID::certify()
+/// [certifications of User Attributes]: user_attribute::UserAttribute::certify()
+/// [`SignatureBuilder`]: signature::SignatureBuilder
 ///
 /// Note: This enum cannot be exhaustively matched to allow future
 /// extensions.
@@ -930,7 +918,7 @@ fn packet_path_iter() {
 /// service vector, if `Signature`s are naively deduplicated.  To
 /// protect against this, consider using [`Signature::normalized_eq`].
 ///
-///   [`Signature::normalized_eq`]: #method.normalized_eq
+///   [`Signature::normalized_eq`]: Signature::normalized_eq()
 ///
 /// # Examples
 ///
@@ -984,7 +972,7 @@ impl Signature {
     /// Gets the version.
     pub fn version(&self) -> u8 {
         match self {
-            &Signature::V4(_) => 4,
+            Signature::V4(_) => 4,
         }
     }
 }
@@ -1028,8 +1016,8 @@ impl DerefMut for Signature {
 /// extensions.
 ///
 /// [Section 5.4 of RFC 4880]: https://tools.ietf.org/html/rfc4880#section-5.4
-/// [`PacketParser`]: ../parse/index.html
-/// [streaming serializer]: ../serialize/stream/index.html
+/// [`PacketParser`]: crate::parse::PacketParser
+/// [streaming serializer]: crate::serialize::stream
 #[non_exhaustive]
 #[derive(PartialEq, Eq, Hash, Clone, Debug)]
 pub enum OnePassSig {
@@ -1042,7 +1030,7 @@ impl OnePassSig {
     /// Gets the version.
     pub fn version(&self) -> u8 {
         match self {
-            &OnePassSig::V3(_) => 3,
+            OnePassSig::V3(_) => 3,
         }
     }
 }
@@ -1087,11 +1075,9 @@ impl DerefMut for OnePassSig {
 /// Note: This enum cannot be exhaustively matched to allow future
 /// extensions.
 ///
-/// [SEIP]: enum.SEIP.html
-/// [AED]: enum.AED.html
 /// [Section 5.1 of RFC 4880]: https://tools.ietf.org/html/rfc4880#section-5.1
-/// [streaming serializer]: ../serialize/stream/index.html
-/// [`PacketParser`]: ../parse/index.html
+/// [streaming serializer]: crate::serialize::stream
+/// [`PacketParser`]: crate::parse::PacketParser
 #[non_exhaustive]
 #[derive(PartialEq, Eq, Hash, Clone, Debug)]
 pub enum PKESK {
@@ -1149,11 +1135,9 @@ impl DerefMut for PKESK {
 /// Note: This enum cannot be exhaustively matched to allow future
 /// extensions.
 ///
-/// [SEIP]: enum.SEIP.html
-/// [AED]: enum.AED.html
 /// [Section 5.3 of RFC 4880]: https://tools.ietf.org/html/rfc4880#section-5.3
-/// [streaming serializer]: ../serialize/stream/index.html
-/// [`PacketParser`]: ../parse/index.html
+/// [streaming serializer]: crate::serialize::stream
+/// [`PacketParser`]: crate::parse::PacketParser
 #[non_exhaustive]
 #[derive(PartialEq, Eq, Hash, Clone, Debug)]
 pub enum SKESK {
@@ -1161,7 +1145,7 @@ pub enum SKESK {
     V4(self::skesk::SKESK4),
     /// SKESK packet version 5.
     ///
-    /// This feature is [experimental](../index.html#experimental-features).
+    /// This feature is [experimental](super#experimental-features).
     V5(self::skesk::SKESK5),
 }
 assert_send_and_sync!(SKESK);
@@ -1170,8 +1154,8 @@ impl SKESK {
     /// Gets the version.
     pub fn version(&self) -> u8 {
         match self {
-            &SKESK::V4(_) => 4,
-            &SKESK::V5(_) => 5,
+            SKESK::V4(_) => 4,
+            SKESK::V5(_) => 5,
         }
     }
 }
@@ -1241,13 +1225,7 @@ impl From<SKESK> for Packet {
 /// [secret keys]: https://tools.ietf.org/html/rfc4880#section-5.5.1.3
 /// [public subkeys]: https://tools.ietf.org/html/rfc4880#section-5.5.1.2
 /// [secret subkeys]: https://tools.ietf.org/html/rfc4880#section-5.5.1.4
-/// [`key::PublicParts`]: key/struct.PublicParts.html
-/// [`key::SecretParts`]: key/struct.SecretParts.html
-/// [`key::UnspecifiedParts`]: key/struct.UnspecifiedParts.html
-/// [`key::PrimaryRole`]: key/struct.PrimaryRole.html
-/// [`key::SubordinateRole`]: key/struct.SubordinateRole.html
-/// [`key::UnspecifiedRole`]: key/struct.UnspecifiedRole.html
-/// [`Cert::keys`]: ../struct.Cert.html#method.keys
+/// [`Cert::keys`]: super::Cert::keys()
 ///
 /// ## Examples
 ///
@@ -1310,20 +1288,20 @@ impl From<SKESK> for Packet {
 ///
 /// It is also possible to use `From`.
 ///
-/// [`Signer`]: ../crypto/trait.Signer.html
-/// [`Key::parts_as_secret`]: enum.Key.html#method.parts_as_secret
-/// [`Key::parts_into_public`]: #method.parts_into_public
-/// [`Key::parts_as_public`]: #method.parts_as_public
-/// [`Key::parts_into_secret`]: #method.parts_into_secret
-/// [`Key::parts_as_secret`]: #method.parts_as_secret
-/// [`Key::parts_into_unspecified`]: #method.parts_into_unspecified
-/// [`Key::parts_as_unspecified`]: #method.parts_as_unspecified
-/// [`Key::role_into_primary`]: #method.role_into_primary
-/// [`Key::role_as_primary`]: #method.role_as_primary
-/// [`Key::role_into_subordinate`]: #method.role_into_subordinate
-/// [`Key::role_as_subordinate`]: #method.role_as_subordinate
-/// [`Key::role_into_unspecified`]: #method.role_into_unspecified
-/// [`Key::role_as_unspecified`]: #method.role_as_unspecified
+/// [`Signer`]: super::crypto::Signer
+/// [`Key::parts_as_secret`]: Key::parts_as_secret()
+/// [`Key::parts_into_public`]: Key::parts_into_public()
+/// [`Key::parts_as_public`]: Key::parts_as_public()
+/// [`Key::parts_into_secret`]: Key::parts_into_secret()
+/// [`Key::parts_as_secret`]: Key::parts_as_secret()
+/// [`Key::parts_into_unspecified`]: Key::parts_into_unspecified()
+/// [`Key::parts_as_unspecified`]: Key::parts_as_unspecified()
+/// [`Key::role_into_primary`]: Key::role_into_primary()
+/// [`Key::role_as_primary`]: Key::role_as_primary()
+/// [`Key::role_into_subordinate`]: Key::role_into_subordinate()
+/// [`Key::role_as_subordinate`]: Key::role_as_subordinate()
+/// [`Key::role_into_unspecified`]: Key::role_into_unspecified()
+/// [`Key::role_as_unspecified`]: Key::role_as_unspecified()
 ///
 /// ## Examples
 ///
@@ -1363,7 +1341,7 @@ impl From<SKESK> for Packet {
 /// converted to a secret key.  This is necessary, for instance, when
 /// creating a [`Signer`]:
 ///
-/// [`Cert`]: ../struct.Cert.html
+/// [`Cert`]: super::Cert
 ///
 /// ```rust
 /// use std::time;
@@ -1411,7 +1389,7 @@ impl From<SKESK> for Packet {
 ///
 /// [the different key formats]: https://tools.ietf.org/html/rfc4880#section-5.5.2
 /// [a proposal for a new key format]: https://tools.ietf.org/html/draft-ietf-openpgp-rfc4880bis-09.html#section-5.5.2
-/// [`Key4::generate_ecc`]: key/struct.Key4.html#method.generate_ecc
+/// [`Key4::generate_ecc`]: key::Key4::generate_ecc()
 ///
 ///
 /// ## Examples
@@ -1436,7 +1414,7 @@ impl From<SKESK> for Packet {
 /// (e.g., to decrypt a message, or to generate a signature).
 ///
 /// [password protect keys]: https://tools.ietf.org/html/rfc4880#section-3.7
-/// [`Key::decrypt_secret`]: #method.decrypt_secret
+/// [`Key::decrypt_secret`]: Key::decrypt_secret()
 ///
 /// # A note on equality
 ///
@@ -1459,8 +1437,8 @@ impl From<SKESK> for Packet {
 /// secret key material is usually encrypted, this can't always be
 /// done automatically.
 ///
-/// [`Key::public_cmp`]: #method.public_cmp
-/// [`Key::public_eq`]: #method.public_eq
+/// [`Key::public_cmp`]: Key::public_cmp()
+/// [`Key::public_eq`]: Key::public_eq()
 ///
 /// Compare:
 ///
@@ -1590,7 +1568,7 @@ impl<R: key::KeyRole> Key<key::SecretParts, R> {
     /// If the `Key` is password protected, you first need to decrypt
     /// it using [`Key::decrypt_secret`].
     ///
-    /// [`Key::decrypt_secret`]: #method.decrypt_secret
+    /// [`Key::decrypt_secret`]: Key::decrypt_secret()
     ///
     /// # Errors
     ///
@@ -1709,7 +1687,9 @@ impl<R: key::KeyRole> Key<key::SecretParts, R> {
     ///
     /// # Examples
     ///
-    /// Encrypt the primary key:
+    /// This example demonstrates how to encrypt the secret key
+    /// material of every key in a certificate.  Decryption can be
+    /// done the same way with [`Key::decrypt_secret`].
     ///
     /// ```rust
     /// use sequoia_openpgp as openpgp;
@@ -1724,19 +1704,31 @@ impl<R: key::KeyRole> Key<key::SecretParts, R> {
     ///     CertBuilder::general_purpose(None,
     ///                                  Some("Alice Lovelace <alice@example.org>"))
     ///         .generate()?;
-    /// let key = cert.primary_key().key().clone().parts_into_secret()?;
-    /// assert!(key.has_unencrypted_secret());
     ///
-    /// // Encrypt the key's secret key material.
-    /// let key = key.encrypt_secret(&"1234".into())?;
-    /// assert!(! key.has_unencrypted_secret());
+    /// // Encrypt every key.
+    /// let mut encrypted_keys: Vec<Packet> = Vec::new();
+    /// for ka in cert.keys().secret() {
+    ///     assert!(ka.has_unencrypted_secret());
     ///
-    /// // Merge it into the certificate.  Note: `Cert::insert_packets`
+    ///     // Encrypt the key's secret key material.
+    ///     let key = ka.key().clone().encrypt_secret(&"1234".into())?;
+    ///     assert!(! key.has_unencrypted_secret());
+    ///
+    ///     // We cannot merge it right now, because `cert` is borrowed.
+    ///     encrypted_keys.push(if ka.primary() {
+    ///         key.role_into_primary().into()
+    ///     } else {
+    ///         key.role_into_subordinate().into()
+    ///     });
+    /// }
+    ///
+    /// // Merge the keys into the certificate.  Note: `Cert::insert_packets`
     /// // prefers added versions of keys.  So, the encrypted version
     /// // will override the decrypted version.
-    /// let cert = cert.insert_packets(Packet::from(key))?;
+    /// let cert = cert.insert_packets(encrypted_keys)?;
     ///
-    /// // Now the primary key's secret key material is encrypted.
+    /// // Now the every key's secret key material is encrypted.  We'll
+    /// // demonstrate this using the primary key:
     /// let key = cert.primary_key().key().parts_as_secret()?;
     /// assert!(! key.has_unencrypted_secret());
     ///
@@ -1770,8 +1762,6 @@ impl<R: key::KeyRole> Key4<key::SecretParts, R> {
     ///
     /// Fails if the secret key is encrypted.  You can use
     /// [`Key::decrypt_secret`] to decrypt a key.
-    ///
-    /// [`Key::decrypt_secret`]: ../enum.Key.html#method.decrypt_secret
     pub fn into_keypair(self) -> Result<KeyPair> {
         let (key, secret) = self.take_secret();
         let secret = match secret {
@@ -1880,8 +1870,8 @@ impl<P: key::KeyParts, R: key::KeyRole> DerefMut for Key<P, R> {
 /// using the [`PacketParser`].
 ///
 /// [Section 5.13 of RFC 4880]: https://tools.ietf.org/html/rfc4880#section-5.13
-/// [streaming serializer]: ../serialize/stream/index.html
-/// [`PacketParser`]: ../parse/index.html
+/// [streaming serializer]: crate::serialize::stream
+/// [`PacketParser`]: crate::parse::PacketParser
 #[derive(PartialEq, Eq, Hash, Clone, Debug)]
 pub enum SEIP {
     /// SEIP packet version 1.
@@ -1939,10 +1929,10 @@ impl DerefMut for SEIP {
 /// using the [streaming serializer], or parsing an encrypted message
 /// using the [`PacketParser`].
 ///
-/// [streaming serializer]: ../serialize/stream/index.html
-/// [`PacketParser`]: ../parse/index.html
+/// [streaming serializer]: crate::serialize::stream
+/// [`PacketParser`]: crate::parse::PacketParser
 ///
-/// This feature is [experimental](../index.html#experimental-features).
+/// This feature is [experimental](super#experimental-features).
 #[non_exhaustive]
 #[derive(PartialEq, Eq, Hash, Clone, Debug)]
 pub enum AED {
